Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/simple_dial_test.py
    :caption: examples/simple_dial_test.py
    :linenos:

.. image:: ../docs/dial.jpg

Two Needles
------------

Example to use dial with two needles

.. literalinclude:: ../examples/simple_dial_two_needles.py
    :caption: examples/simple_dial_two_needles.py
    :linenos:


Functional clock
-----------------

Example of a functional clock

.. literalinclude:: ../examples/simple_dial_clock.py
    :caption: examples/simple_dial_clock.py
    :linenos:

.. image:: ../docs/watchwatch.gif
